@@ -7,7 +7,7 @@ import (
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
 
-	"github.com/openshift/cluster-logging-operator/pkg/logger"
+	"github.com/ViaQ/logerr/log"
 	"github.com/openshift/cluster-logging-operator/test/helpers/oc"
 )
 
@@ -74,7 +74,7 @@ var _ = Describe("oc exec pod", func() {
 					if tmpFile != nil {
 						_ = os.Remove(tmpFile.Name())
 					} else {
-						logger.Error("tmpfile is nil")
+						log.Info("tmpfile is nil")
 					}
 				})
 			})
@@ -138,7 +138,7 @@ var _ = Describe("oc exec pod", func() {
 					if tmpFile != nil {
 						os.Remove(tmpFile.Name())
 					} else {
-						logger.Error("tmpfile is nil")
+						log.Info("tmpfile is nil")
 					}
 				})
 			})
